==> dojo-1.10.6.tgz: package/cldr/nls/sr/japanese.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "ове суботе",
	"field-sat-relative+1": "следеће суботе",
	"field-dayperiod": "пре подне/поподне",
	"field-sun-relative+-1": "прошле недеље",
	"field-mon-relative+-1": "прошлог понедељка",
	"field-minute": "минут",
	"field-day-relative+-1": "јуче",
	"field-weekday": "дан у недељи",
	"field-day-relative+-2": "прекјуче",
	"field-era": "ера",
	"field-hour": "час",
	"field-sun-relative+0": "ове недеље",
	"field-sun-relative+1": "следеће недеље",
	"field-wed-relative+-1": "прошле среде",
	"field-day-relative+0": "данас",
	"field-day-relative+1": "сутра",
	"eraAbbr": [
		"Таика (645-650)",
		"Хакучи (650-671)",
		"Хакухо (672-686)",
		"Шучо (686-701)",
		"Таихо (701-704)",
		"Кеиун (704-708)",
		"Вадо (708-715)",
		"Реики (715-717)",
		"Јоро (717-724)",
		"Јинки (724-729)",
		"Темпио (729-749)",
		"Темпио-кампо (749-749)",
		"Темпио-шохо (749-757)",
		"Темпио-хођи (757-765)",
		"Темпо-ђинго (765-767)",
		"Ђинго-кеиун (767-770)",
		"Хоки (770-780)",
		"Тен-о (781-782)",
		"Енрјаку (782-806)",
		"Даидо (806-810)",
		"Конин (810-824)",
		"Тенчо (824-834)",
		"Шова (834-848)",
		"Кајо (848-851)",
		"Нињу (851-854)",
		"Саико (854-857)",
		"Тенан (857-859)",
		"Јоган (859-877)",
		"Генкеи (877-885)",
		"Ниња (885-889)",
		"Кампјо (889-898)",
		"Шотаи (898-901)",
		"Енђи (901-923)",
		"Енчо (923-931)",
		"Шохеи (931-938)",
		"Тенгјо (938-947)",
		"Тенриаку (947-957)",
		"Тентоку (957-961)",
		"Ова (961-964)",
		"Кохо (964-968)",
		"Ана (968-970)",
		"Тенроку (970-973)",
		"Тен-ен (973-976)",
		"Јоген (976-978)",
		"Тенген (978-983)",
		"Еикан (983-985)",
		"Кана (985-987)",
		"Еи-ен (987-989)",
		"Еисо (989-990)",
		"Шорјаку (990-995)",
		"Чотоку (995-999)",
		"Чохо (999-1004)",
		"Канко (1004-1012)",
		"Чова (1012-1017)",
		"Канин (1017-1021)",
		"Ђиан (1021-1024)",
		"Мању (1024-1028)",
		"Чоген (1028-1037)",
		"Чорјаку (1037-1040)",
		"Чокју (1040-1044)",
		"Кантоку (1044-1046)",
		"Еишо (1046-1053)",
		"Тенђи (1053-1058)",
		"Кохеи (1058-1065)",
		"Ђирјаку (1065-1069)",
		"Енкју (1069-1074)",
		"Шохо (1074-1077)",
		"Шорјаку (1077-1081)",
		"Еишо (1081-1084)",
		"Отоку (1084-1087)",
		"Канђи (1087-1094)",
		"Кахо (1094-1096)",
		"Еичо (1096-1097)",
		"Шотоку (1097-1099)",
		"Кова (1099-1104)",
		"Чођи (1104-1106)",
		"Кашо (1106-1108)",
		"Тенин (1108-1110)",
		"Тен-еи (1110-1113)",
		"Еикју (1113-1118)",
		"Ђен-еи (1118-1120)",
		"Хоан (1120-1124)",
		"Тенђи (1124-1126)",
		"Даиђи (1126-1131)",
		"Теншо (1131-1132)",
		"Чошао (1132-1135)",
		"Хоен (1135-1141)",
		"Еиђи (1141-1142)",
		"Кођи (1142-1144)",
		"Тењо (1144-1145)",
		"Кјуан (1145-1151)",
		"Нинпеи (1151-1154)",
		"Кјују (1154-1156)",
		"Хоген (1156-1159)",
		"Хеиђи (1159-1160)",
		"Еирјаку (1160-1161)",
		"Охо (1161-1163)",
		"Чокан (1163-1165)",
		"Еиман (1165-1166)",
		"Нин-ан (1166-1169)",
		"Као (1169-1171)",
		"Шоан (1171-1175)",
		"Анген (1175-1177)",
		"Ђишо (1177-1181)",
		"Јова (1181-1182)",
		"Ђуеи (1182-1184)",
		"Генрјуку (1184-1185)",
		"Бунђи (1185-1190)",
		"Кенкју (1190-1199)",
		"Шођи (1199-1201)",
		"Кенин (1201-1204)",
		"Генкју (1204-1206)",
		"Кен-еи (1206-1207)",
		"Шоген (1207-1211)",
		"Кенрјаку (1211-1213)",
		"Кенпо (1213-1219)",
		"Шокју (1219-1222)",
		"Ђу (1222-1224)",
		"Ђенин (1224-1225)",
		"Кароку (1225-1227)",
		"Антеи (1227-1229)",
		"Канки (1229-1232)",
		"Ђоеи (1232-1233)",
		"Темпуку (1233-1234)",
		"Бунрјаку (1234-1235)",
		"Катеи (1235-1238)",
		"Рјакунин (1238-1239)",
		"Ен-о (1239-1240)",
		"Нињи (1240-1243)",
		"Канген (1243-1247)",
		"Хођи (1247-1249)",
		"Кенчо (1249-1256)",
		"Коген (1256-1257)",
		"Шока (1257-1259)",
		"Шоген (1259-1260)",
		"Бун-о (1260-1261)",
		"Кочо (1261-1264)",
		"Бун-еи (1264-1275)",
		"Кенђи (1275-1278)",
		"Коан (1278-1288)",
		"Шу (1288-1293)",
		"Еинин (1293-1299)",
		"Шоан (1299-1302)",
		"Кенген (1302-1303)",
		"Каген (1303-1306)",
		"Токуђи (1306-1308)",
		"Енкеи (1308-1311)",
		"Очо (1311-1312)",
		"Шова (1312-1317)",
		"Бунпо (1317-1319)",
		"Ђено (1319-1321)",
		"Ђенкјо (1321-1324)",
		"Шочу (1324-1326)",
		"Кареки (1326-1329)",
		"Гентоку (1329-1331)",
		"Генко (1331-1334)",
		"Кему (1334-1336)",
		"Енген (1336-1340)",
		"Кококу (1340-1346)",
		"Шохеи (1346-1370)",
		"Кентоку (1370-1372)",
		"Бучу (1372-1375)",
		"Тењу (1375-1379)",
		"Корјаку (1379-1381)",
		"Кова (1381-1384)",
		"Генчу (1384-1392)",
		"Меитоку (1384-1387)",
		"Какеи (1387-1389)",
		"Ку (1389-1390)",
		"Меитоку (1390-1394)",
		"Оеи (1394-1428)",
		"Шочо (1428-1429)",
		"Еикјо (1429-1441)",
		"Какитсу (1441-1444)",
		"Бун-ан (1444-1449)",
		"Хотоку (1449-1452)",
		"Кјотоку (1452-1455)",
		"Кошо (1455-1457)",
		"Чороку (1457-1460)",
		"Каншо (1460-1466)",
		"Буншо (1466-1467)",
		"Онин (1467-1469)",
		"Бунмеи (1469-1487)",
		"Чокјо (1487-1489)",
		"Ентоку (1489-1492)",
		"Меио (1492-1501)",
		"Бунки (1501-1504)",
		"Еишо (1504-1521)",
		"Таиеи (1521-1528)",
		"Кјороку (1528-1532)",
		"Тенмон (1532-1555)",
		"Кођи (1555-1558)",
		"Еироку (1558-1570)",
		"Генки (1570-1573)",
		"Теншо (1573-1592)",
		"Бунроку (1592-1596)",
		"Кеичо (1596-1615)",
		"Генва (1615-1624)",
		"Кан-еи (1624-1644)",
		"Шохо (1644-1648)",
		"Кеиан (1648-1652)",
		"Шу (1652-1655)",
		"Меирјаку (1655-1658)",
		"Мањи (1658-1661)",
		"Канбун (1661-1673)",
		"Енпо (1673-1681)",
		"Тенва (1681-1684)",
		"Јокјо (1684-1688)",
		"Генроку (1688-1704)",
		"Хоеи (1704-1711)",
		"Шотоку (1711-1716)",
		"Кјохо (1716-1736)",
		"Генбун (1736-1741)",
		"Канпо (1741-1744)",
		"Енкјо (1744-1748)",
		"Кан-ен (1748-1751)",
		"Хорјаку (1751-1764)",
		"Меива (1764-1772)",
		"Ан-еи (1772-1781)",
		"Тенмеи (1781-1789)",
		"Кансеи (1789-1801)",
		"Кјова (1801-1804)",
		"Бунка (1804-1818)",
		"Бунсеи (1818-1830)",
		"Тенпо (1830-1844)",
		"Кока (1844-1848)",
		"Каеи (1848-1854)",
		"Ансеи (1854-1860)",
		"Ман-ен (1860-1861)",
		"Бункју (1861-1864)",
		"Генђи (1864-1865)",
		"Кеико (1865-1868)",
		"Меиђи",
		"Таишо",
		"Шова",
		"Хаисеи"
	],
	"field-day-relative+2": "прекосутра",
	"dateFormat-long": "MMMM d, y G",
	"field-tue-relative+0": "овог уторка",
	"field-zone": "зона",
	"field-tue-relative+1": "следећег уторка",
	"field-week-relative+-1": "Прошле недеље",
	"dateFormat-medium": "MMM d, y G",
	"field-year-relative+0": "Ове године",
	"field-year-relative+1": "Следеће године",
	"field-sat-relative+-1": "прошле суботе",
	"field-year-relative+-1": "Прошле године",
	"field-year": "година",
	"field-fri-relative+0": "овог петка",
	"field-fri-relative+1": "следећег петка",
	"field-week": "недеља",
	"field-week-relative+0": "Ове недеље",
	"field-week-relative+1": "Следеће недеље",
	"field-month-relative+0": "Овог месеца",
	"field-month": "месец",
	"field-month-relative+1": "Следећег месеца",
	"field-fri-relative+-1": "прошлог петка",
	"field-second": "секунд",
	"field-tue-relative+-1": "прошлог уторка",
	"field-day": "дан",
	"field-mon-relative+0": "овог понедељка",
	"field-mon-relative+1": "следећег понедељка",
	"field-thu-relative+0": "овог четвртка",
	"field-second-relative+0": "сада",
	"dateFormat-short": "M/d/yy G",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormat-full": "EEEE, MMMM d, y G",
	"field-wed-relative+0": "ове среде",
	"field-wed-relative+1": "следеће среде",
	"field-month-relative+-1": "Прошлог месеца",
	"field-thu-relative+-1": "прошлог четвртка"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/sr/japanese.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "у суботу",
	"field-sat-relative+1": "следеће суботе",
	"field-dayperiod": "пре подне/по подне",
	"field-sun-relative+-1": "прошле недеље",
	"field-mon-relative+-1": "прошлог понедељка",
	"field-minute": "минут",
	"field-day-relative+-1": "јуче",
	"field-weekday": "дан у недељи",
	"field-day-relative+-2": "прекјуче",
	"field-era": "ера",
	"field-hour": "сат",
	"field-sun-relative+0": "у недељу",
	"field-sun-relative+1": "следеће недеље",
	"field-wed-relative+-1": "прошле среде",
	"field-day-relative+0": "данас",
	"field-day-relative+1": "сутра",
	"eraAbbr": [
		"Таика (645-650)",
		"Хакучи (650-671)",
		"Хакухо (672-686)",
		"Шучо (686-701)",
		"Таихо (701-704)",
		"Кеиун (704-708)",
		"Вадо (708-715)",
		"Реики (715-717)",
		"Јоро (717-724)",
		"Јинки (724-729)",
		"Темпио (729-749)",
		"Темпио-кампо (749-749)",
		"Темпио-шохо (749-757)",
		"Темпио-хођи (757-765)",
		"Темпо-ђинго (765-767)",
		"Ђинго-кеиун (767-770)",
		"Хоки (770-780)",
		"Тен-о (781-782)",
		"Енрјаку (782-806)",
		"Даидо (806-810)",
		"Конин (810-824)",
		"Тенчо (824-834)",
		"Шова (834-848)",
		"Кајо (848-851)",
		"Нињу (851-854)",
		"Саико (854-857)",
		"Тенан (857-859)",
		"Јоган (859-877)",
		"Генкеи (877-885)",
		"Ниња (885-889)",
		"Кампјо (889-898)",
		"Шотаи (898-901)",
		"Енђи (901-923)",
		"Енчо (923-931)",
		"Шохеи (931-938)",
		"Тенгјо (938-947)",
		"Тенриаку (947-957)",
		"Тентоку (957-961)",
		"Ова (961-964)",
		"Кохо (964-968)",
		"Ана (968-970)",
		"Тенроку (970-973)",
		"Тен-ен (973-976)",
		"Јоген (976-978)",
		"Тенген (978-983)",
		"Еикан (983-985)",
		"Кана (985-987)",
		"Еи-ен (987-989)",
		"Еисо (989-990)",
		"Шорјаку (990-995)",
		"Чотоку (995-999)",
		"Чохо (999-1004)",
		"Канко (1004-1012)",
		"Чова (1012-1017)",
		"Канин (1017-1021)",
		"Ђиан (1021-1024)",
		"Мању (1024-1028)",
		"Чоген (1028-1037)",
		"Чорјаку (1037-1040)",
		"Чокју (1040-1044)",
		"Кантоку (1044-1046)",
		"Еишо (1046-1053)",
		"Тенђи (1053-1058)",
		"Кохеи (1058-1065)",
		"Ђирјаку (1065-1069)",
		"Енкју (1069-1074)",
		"Шохо (1074-1077)",
		"Шорјаку (1077-1081)",
		"Еишо (1081-1084)",
		"Отоку (1084-1087)",
		"Канђи (1087-1094)",
		"Кахо (1094-1096)",
		"Еичо (1096-1097)",
		"Шотоку (1097-1099)",
		"Кова (1099-1104)",
		"Чођи (1104-1106)",
		"Кашо (1106-1108)",
		"Тенин (1108-1110)",
		"Тен-еи (1110-1113)",
		"Еикју (1113-1118)",
		"Ђен-еи (1118-1120)",
		"Хоан (1120-1124)",
		"Тенђи (1124-1126)",
		"Даиђи (1126-1131)",
		"Теншо (1131-1132)",
		"Чошао (1132-1135)",
		"Хоен (1135-1141)",
		"Еиђи (1141-1142)",
		"Кођи (1142-1144)",
		"Тењо (1144-1145)",
		"Кјуан (1145-1151)",
		"Нинпеи (1151-1154)",
		"Кјују (1154-1156)",
		"Хоген (1156-1159)",
		"Хеиђи (1159-1160)",
		"Еирјаку (1160-1161)",
		"Охо (1161-1163)",
		"Чокан (1163-1165)",
		"Еиман (1165-1166)",
		"Нин-ан (1166-1169)",
		"Као (1169-1171)",
		"Шоан (1171-1175)",
		"Анген (1175-1177)",
		"Ђишо (1177-1181)",
		"Јова (1181-1182)",
		"Ђуеи (1182-1184)",
		"Генрјуку (1184-1185)",
		"Бунђи (1185-1190)",
		"Кенкју (1190-1199)",
		"Шођи (1199-1201)",
		"Кенин (1201-1204)",
		"Генкју (1204-1206)",
		"Кен-еи (1206-1207)",
		"Шоген (1207-1211)",
		"Кенрјаку (1211-1213)",
		"Кенпо (1213-1219)",
		"Шокју (1219-1222)",
		"Ђу (1222-1224)",
		"Ђенин (1224-1225)",
		"Кароку (1225-1227)",
		"Антеи (1227-1229)",
		"Канки (1229-1232)",
		"Ђоеи (1232-1233)",
		"Темпуку (1233-1234)",
		"Бунрјаку (1234-1235)",
		"Катеи (1235-1238)",
		"Рјакунин (1238-1239)",
		"Ен-о (1239-1240)",
		"Нињи (1240-1243)",
		"Канген (1243-1247)",
		"Хођи (1247-1249)",
		"Кенчо (1249-1256)",
		"Коген (1256-1257)",
		"Шока (1257-1259)",
		"Шоген (1259-1260)",
		"Бун-о (1260-1261)",
		"Кочо (1261-1264)",
		"Бун-еи (1264-1275)",
		"Кенђи (1275-1278)",
		"Коан (1278-1288)",
		"Шу (1288-1293)",
		"Еинин (1293-1299)",
		"Шоан (1299-1302)",
		"Кенген (1302-1303)",
		"Каген (1303-1306)",
		"Токуђи (1306-1308)",
		"Енкеи (1308-1311)",
		"Очо (1311-1312)",
		"Шова (1312-1317)",
		"Бунпо (1317-1319)",
		"Ђено (1319-1321)",
		"Ђенкјо (1321-1324)",
		"Шочу (1324-1326)",
		"Кареки (1326-1329)",
		"Гентоку (1329-1331)",
		"Генко (1331-1334)",
		"Кему (1334-1336)",
		"Енген (1336-1340)",
		"Кококу (1340-1346)",
		"Шохеи (1346-1370)",
		"Кентоку (1370-1372)",
		"Бучу (1372-1375)",
		"Тењу (1375-1379)",
		"Корјаку (1379-1381)",
		"Кова (1381-1384)",
		"Генчу (1384-1392)",
		"Меитоку (1384-1387)",
		"Какеи (1387-1389)",
		"Ку (1389-1390)",
		"Меитоку (1390-1394)",
		"Оеи (1394-1428)",
		"Шочо (1428-1429)",
		"Еикјо (1429-1441)",
		"Какитсу (1441-1444)",
		"Бун-ан (1444-1449)",
		"Хотоку (1449-1452)",
		"Кјотоку (1452-1455)",
		"Кошо (1455-1457)",
		"Чороку (1457-1460)",
		"Каншо (1460-1466)",
		"Буншо (1466-1467)",
		"Онин (1467-1469)",
		"Бунмеи (1469-1487)",
		"Чокјо (1487-1489)",
		"Ентоку (1489-1492)",
		"Меио (1492-1501)",
		"Бунки (1501-1504)",
		"Еишо (1504-1521)",
		"Таиеи (1521-1528)",
		"Кјороку (1528-1532)",
		"Тенмон (1532-1555)",
		"Кођи (1555-1558)",
		"Еироку (1558-1570)",
		"Генки (1570-1573)",
		"Теншо (1573-1592)",
		"Бунроку (1592-1596)",
		"Кеичо (1596-1615)",
		"Генва (1615-1624)",
		"Кан-еи (1624-1644)",
		"Шохо (1644-1648)",
		"Кеиан (1648-1652)",
		"Шу (1652-1655)",
		"Меирјаку (1655-1658)",
		"Мањи (1658-1661)",
		"Канбун (1661-1673)",
		"Енпо (1673-1681)",
		"Тенва (1681-1684)",
		"Јокјо (1684-1688)",
		"Генроку (1688-1704)",
		"Хоеи (1704-1711)",
		"Шотоку (1711-1716)",
		"Кјохо (1716-1736)",
		"Генбун (1736-1741)",
		"Канпо (1741-1744)",
		"Енкјо (1744-1748)",
		"Кан-ен (1748-1751)",
		"Хорјаку (1751-1764)",
		"Меива (1764-1772)",
		"Ан-еи (1772-1781)",
		"Тенмеи (1781-1789)",
		"Кансеи (1789-1801)",
		"Кјова (1801-1804)",
		"Бунка (1804-1818)",
		"Бунсеи (1818-1830)",
		"Тенпо (1830-1844)",
		"Кока (1844-1848)",
		"Каеи (1848-1854)",
		"Ансеи (1854-1860)",
		"Ман-ен (1860-1861)",
		"Бункју (1861-1864)",
		"Генђи (1864-1865)",
		"Кеико (1865-1868)",
		"Меиђи",
		"Таишо",
		"Шова",
		"Хаисеи"
	],
	"field-day-relative+2": "прекосутра",
	"dateFormat-long": "MMMM d, y G",
	"field-tue-relative+0": "у уторак",
	"field-zone": "временска зона",
	"field-tue-relative+1": "следећег уторка",
	"field-week-relative+-1": "прошле недеље",
	"dateFormat-medium": "MMM d, y G",
	"field-year-relative+0": "ове године",
	"field-year-relative+1": "следеће године",
	"field-sat-relative+-1": "прошле суботе",
	"field-year-relative+-1": "прошле године",
	"field-year": "година",
	"field-fri-relative+0": "у петак",
	"field-fri-relative+1": "следећег петка",
	"field-week": "недеља",
	"field-week-relative+0": "ове недеље",
	"field-week-relative+1": "следеће недеље",
	"field-month-relative+0": "овог месеца",
	"field-month": "месец",
	"field-month-relative+1": "следећег месеца",
	"field-fri-relative+-1": "прошлог петка",
	"field-second": "секунд",
	"field-tue-relative+-1": "прошлог уторка",
	"field-day": "дан",
	"field-mon-relative+0": "у понедељак",
	"field-mon-relative+1": "следећег понедељка",
	"field-thu-relative+0": "у четвртак",
	"field-second-relative+0": "сада",
	"dateFormat-short": "M/d/yy G",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormat-full": "EEEE, MMMM d, y G",
	"field-wed-relative+0": "у среду",
	"field-wed-relative+1": "следеће среде",
	"field-month-relative+-1": "прошлог месеца",
	"field-thu-relative+-1": "прошлог четвртка"
}
//end v1.x content
);
